import { LitElement as x, unsafeCSS as v, html as o, nothing as r } from "lit";
import { query as b, property as n, state as c } from "lit/decorators.js";
import { live as m } from "lit/directives/live.js";
import { unsafeSVG as h } from "lit/directives/unsafe-svg.js";
import { FormControlMixin as g } from "@open-wc/form-control";
import { event as f } from "../../utils/event.js";
import { innerInputValidators as y } from "../../utils/validators.js";
import "../button/index.js";
import "../label/index.js";
import "../spinner/index.js";
const w = `:host {
  display: inline-block;
  width: var(--dfx-input-width);

  --dfx-input-border-radius: var(--dfx-border-radius-m, 0.375rem);
  --dfx-input-color-background: var(--dfx-color-background-light, #ffffff);
  --dfx-input-color-text: var(--dfx-color-text-dark, #383d46);
  --dfx-input-font-family: var(
    --dfx-font-family,
    -apple-system,
    BlinkMacSystemFont,
    'Segoe UI',
    Roboto,
    Arial,
    sans-serif
  );
  --dfx-input-font-size: var(--dfx-font-size-m, 0.875rem);
  --dfx-input-gap: calc(var(--dfx-size-xs, 0.75rem) / 2);
  --dfx-input-height: calc(var(--dfx-input-icon-size) + 2 * var(--dfx-input-padding));
  --dfx-input-icon-size: var(--dfx-size-xl, 1.5rem);
  --dfx-input-padding: calc(var(--dfx-size-xs, 0.75rem) / 2);
  --dfx-input-text-align: start;
  --dfx-input-transition: all var(--dfx-transition-medium, 0.2s ease-in-out);
  --dfx-input-width: calc(var(--dfx-size-3xl, 2.5rem) * 5);
}

:host([hidden]) {
  display: none;
}

:host([disabled]) [part='container'] {
  --dfx-input-color-background: var(--dfx-color-background-light-variant, #f0f2f4);
  --dfx-input-color-text: var(--dfx-color-text-light, #676f7d);
  opacity: var(--dfx-form-disabled-opacity, 0.5);
}

:host([disabled]) [part='control'] {
  cursor: not-allowed;
}

:host([disabled]) input {
  pointer-events: none;
}

[part='container'] {
  display: grid;
  gap: calc(var(--dfx-input-gap) + var(--dfx-size-4xs, 0.125rem));
}

[part='control'] {
  display: flex;
  align-items: center;
  box-sizing: border-box;
  width: 100%;
  height: var(--dfx-input-height);
  padding: var(--dfx-input-padding);
  font-family: var(--dfx-input-font-family);
  border-radius: var(--dfx-input-border-radius);
  box-shadow: var(--dfx-form-border, inset 0 0 0 0.05rem #979fab);
  background-color: var(--dfx-input-color-background);
  transition: var(--dfx-input-transition);
  border: none;
  margin: 0;
}

:host(:not([disabled])) :not(.invalid) [part='control']:has(:focus, :active) {
  box-shadow: var(--dfx-form-border-active, inset 0 0 0 0.1rem #20242c);
}

.invalid [part='control'] {
  box-shadow: var(--dfx-form-border-error, inset 0 0 0 0.05rem #c91f3a);
}

.invalid [part='control']:has(:focus, :active) {
  box-shadow: var(--dfx-form-border-error-active, inset 0 0 0 0.1rem #c91f3a);
}

input {
  width: 100%;
  outline: 0;
  border: 0;
  box-sizing: border-box;
  padding-inline: var(--dfx-input-gap);
  color: var(--dfx-input-color-text);
  font-family: var(--dfx-input-font-family);
  font-size: var(--dfx-input-font-size);
  text-align: var(--dfx-input-text-align);
  background-color: transparent;

  &::placeholder {
    color: var(--dfx-color-text-dark-variant, #20242c);
    opacity: var(--dfx-form-disabled-opacity, 0.5);
  }
}

input[type='date'],
input[type='datetime-local'],
input[type='month'],
input[type='time'],
input[type='week'] {
  padding-right: calc(var(--dfx-input-gap) / 2);
}

input[type='number']::-webkit-outer-spin-button,
input[type='number']::-webkit-inner-spin-button,
input[type='search']::-webkit-search-decoration,
input[type='search']::-webkit-search-cancel-button,
input[type='search']::-webkit-search-results-button,
input[type='search']::-webkit-search-results-decoration {
  display: none;
}

input[type='number'] {
  --dfx-input-text-align: center;
  appearance: textfield;
}

::slotted(*) {
  box-sizing: border-box;
  color: var(--dfx-color-text-light, #676f7d);
  font-size: var(--dfx-input-font-size);
}

::slotted(span[slot='start']) {
  padding-left: var(--dfx-input-gap);
}

::slotted(span[slot='end']) {
  padding-right: var(--dfx-input-gap);
}

::slotted(svg) {
  box-sizing: border-box;
  width: var(--dfx-input-icon-size);
  height: var(--dfx-input-icon-size);
  padding: var(--dfx-size-4xs, 0.125rem);
}

::slotted(dfx-button),
dfx-button {
  --dfx-button-height: var(--dfx-input-icon-size);
  --dfx-button-padding: var(--dfx-size-4xs, 0.125rem);
  --dfx-button-focus-offset: calc(var(--dfx-form-outline-offset, 0.2rem) / 2);
  --dfx-button-scale-active: 1;
}

dfx-spinner {
  --dfx-spinner-color: var(--dfx-color-text-light, #676f7d);
  --dfx-spinner-size: var(--dfx-input-icon-size);
  --dfx-spinner-padding: var(--dfx-size-4xs, 0.125rem);
}
`, k = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
  <path stroke-linecap="round" stroke-linejoin="round" d="M3.98 8.223A10.477 10.477 0 001.934 12C3.226 16.338 7.244 19.5 12 19.5c.993 0 1.953-.138 2.863-.395M6.228 6.228A10.45 10.45 0 0112 4.5c4.756 0 8.773 3.162 10.065 7.498a10.523 10.523 0 01-4.293 5.774M6.228 6.228L3 3m3.228 3.228l3.65 3.65m7.894 7.894L21 21m-3.228-3.228l-3.65-3.65m0 0a3 3 0 10-4.243-4.243m4.242 4.242L9.88 9.88" />
</svg>
`, $ = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
  <path stroke-linecap="round" stroke-linejoin="round" d="M2.036 12.322a1.012 1.012 0 010-.639C3.423 7.51 7.36 4.5 12 4.5c4.638 0 8.573 3.007 9.963 7.178.07.207.07.431 0 .639C20.577 16.49 16.64 19.5 12 19.5c-4.638 0-8.573-3.007-9.963-7.178z" />
  <path stroke-linecap="round" stroke-linejoin="round" d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
</svg>
`, z = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6">
  <path stroke-linecap="round" stroke-linejoin="round" d="M19.5 12h-15" />
</svg>
`, C = `<svg width="100%" height="100%" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-6 h-6">
  <path stroke-linecap="round" stroke-linejoin="round" d="M12 4.5v15m7.5-7.5h-15" />
</svg>
`;
var I = Object.defineProperty, S = Object.getOwnPropertyDescriptor, t = (l, i, s, d) => {
  for (var a = d > 1 ? void 0 : d ? S(i, s) : i, p = l.length - 1, u; p >= 0; p--)
    (u = l[p]) && (a = (d ? u(i, s, a) : u(a)) || a);
  return d && a && I(i, s, a), a;
};
class e extends g(x) {
  constructor() {
    super(...arguments), this.value = "", this.type = "text", this.required = !1, this.disabled = !1, this.loading = !1, this.readonly = !1, this.hideLabel = !1, this.dirty = !1, this.passwordVisible = !1, this.#e = Math.random().toString(36).substring(2);
  }
  static {
    this.styles = v(w);
  }
  static {
    this.formControlValidators = y;
  }
  connectedCallback() {
    super.connectedCallback(), this.addEventListener("invalid", this.#n), this.addEventListener("keydown", this.#i);
  }
  disconnectedCallback() {
    super.disconnectedCallback(), this.removeEventListener("invalid", this.#n), this.removeEventListener("keydown", this.#i);
  }
  #n() {
    this.dirty = !0;
  }
  #i(i) {
    i.code === "Enter" && this.form?.requestSubmit();
  }
  #o(i) {
    this.value = i.target.value, this.onInput.emit(this.value);
  }
  #a(i) {
    this.dirty = !0, this.value = i.target.value, this.onChange.emit(this.value);
  }
  #r() {
    this.value = this.validationTarget.value, this.dirty = !0, this.onInput.emit(this.value), this.onChange.emit(this.value);
  }
  #s() {
    this.validationTarget.stepDown(), this.#r();
  }
  #d() {
    this.validationTarget.stepUp(), this.#r();
  }
  #l() {
    this.passwordVisible = !this.passwordVisible;
  }
  validityCallback() {
    return this.onInvalid.emit(this.internals.validity), this.validationTarget?.validationMessage;
  }
  async updated(i) {
    i.has("value") && (this.setValue(this.value), await this.validationComplete, this.requestUpdate());
  }
  resetFormControl() {
    this.dirty = !1, this.value = this.getAttribute("value") ?? "";
  }
  #p() {
    return o`<dfx-label type="error" id="label">${this.validationMessage}</dfx-label>`;
  }
  #u() {
    return this.helperText ? o`<dfx-label type="helper" id="label">${this.helperText}</dfx-label>` : o``;
  }
  #h() {
    return o`
      <dfx-button
        part="button"
        variant="text"
        label="Decrease value by ${this.step ?? 1}"
        ?disabled=${this.disabled || (this.min !== void 0 ? Number(this.value) <= this.min : !1)}
        @dfx-click="${this.#s}"
      >
        ${h(z)}
      </dfx-button>
    `;
  }
  #f() {
    return o`
      <dfx-button
        part="button"
        variant="text"
        label="Increase value by ${this.step ?? 1}"
        ?disabled=${this.disabled || (this.max !== void 0 ? Number(this.value) >= this.max : !1)}
        @dfx-click="${this.#d}"
      >
        ${h(C)}
      </dfx-button>
    `;
  }
  #c() {
    return o`
      <dfx-button
        part="button"
        variant="text"
        label="Toggle password visibility"
        ?disabled=${this.disabled}
        @dfx-click="${this.#l}"
      >
        ${h(this.passwordVisible ? k : $)}
      </dfx-button>
    `;
  }
  #x() {
    return this.type === "number" ? this.#h() : o``;
  }
  #v() {
    return this.type === "password" ? this.#c() : this.type === "number" ? this.#f() : o``;
  }
  #b() {
    return this.loading ? o`<dfx-spinner size="small"></dfx-spinner>` : o``;
  }
  #m() {
    return o`<label for=${this.#e}><dfx-label>${this.label}</dfx-label></label>`;
  }
  /** @ignore */
  get #t() {
    return !this.validity.valid && this.dirty;
  }
  #e;
  render() {
    const i = this.passwordVisible ? "text" : "password", s = this.type === "password" ? i : this.type;
    return o`
      <div part="container" class=${this.#t ? "invalid" : r}>
        ${this.label && !this.hideLabel ? this.#m() : r}
        <div part="control">
          <slot name="start"> ${this.#x()} </slot>
          <input
            id=${this.#e}
            part="input"
            .value=${m(this.value)}
            type=${s}
            inputmode="${this.inputmode ?? r}"
            autocomplete="${this.autocomplete ?? r}"
            placeholder="${this.placeholder ?? r}"
            minlength="${this.minlength ?? r}"
            maxlength="${this.maxlength ?? r}"
            min="${this.min ?? r}"
            max="${this.max ?? r}"
            pattern="${this.pattern ?? r}"
            step="${this.step ?? r}"
            ?required=${this.required}
            ?disabled=${this.disabled}
            ?readonly=${this.readonly}
            @input=${this.#o}
            @change=${this.#a}
            aria-label=${this.label && this.hideLabel ? this.label : r}
            aria-invalid=${this.#t}
            aria-describedby=${this.helperText || this.#t ? "label" : r}
          />
          <slot name="end"> ${this.#b()} ${this.#v()} </slot>
        </div>
        ${this.#t ? this.#p() : this.#u()}
      </div>
    `;
  }
}
t([
  b("input")
], e.prototype, "validationTarget", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "name", 2);
t([
  n({ type: String })
], e.prototype, "value", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "type", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "label", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "placeholder", 2);
t([
  n({ type: Boolean, reflect: !0 })
], e.prototype, "required", 2);
t([
  n({ type: Number, reflect: !0 })
], e.prototype, "minlength", 2);
t([
  n({ type: Number, reflect: !0 })
], e.prototype, "maxlength", 2);
t([
  n({ type: Number, reflect: !0 })
], e.prototype, "min", 2);
t([
  n({ type: Number, reflect: !0 })
], e.prototype, "max", 2);
t([
  n({ type: Number, reflect: !0 })
], e.prototype, "step", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "pattern", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "autocomplete", 2);
t([
  n({ type: Boolean, reflect: !0 })
], e.prototype, "disabled", 2);
t([
  n({ type: Boolean, reflect: !0 })
], e.prototype, "loading", 2);
t([
  n({ type: Boolean, reflect: !0 })
], e.prototype, "readonly", 2);
t([
  n({ type: String, reflect: !0 })
], e.prototype, "inputmode", 2);
t([
  n({ type: String, attribute: "helper-text", reflect: !0 })
], e.prototype, "helperText", 2);
t([
  n({ type: Boolean, attribute: "hide-label", reflect: !0 })
], e.prototype, "hideLabel", 2);
t([
  f("dfx-input")
], e.prototype, "onInput", 2);
t([
  f("dfx-change")
], e.prototype, "onChange", 2);
t([
  f("dfx-invalid")
], e.prototype, "onInvalid", 2);
t([
  c()
], e.prototype, "dirty", 2);
t([
  c()
], e.prototype, "passwordVisible", 2);
export {
  e as Input
};
//# sourceMappingURL=input.js.map
