import { LitElement, PropertyValues, TemplateResult } from 'lit';
import '../label/index.js';
declare const RadioGroup_base: import("@open-wc/form-control").Constructor<import("@open-wc/form-control").FormControlInterface> & typeof LitElement;
/**
 * Creates a form group of radios.
 *
 * @element dfx-radio-group
 * @slot {html} slot - Default slot for `<dfx-radio>` elements
 * @fires {string | null} dfx-change - Fires when value of radio group changes
 * @fires {ValidityState} dfx-invalid - Fires when state of radio group is invalid
 * @cssprop [--dfx-checkbox-group-direction=column] - Direction of radios
 * @cssprop [--dfx-checkbox-group-gap=var(--dfx-size-2xs, 0.5rem)] - Gap between radios
 * @csspart fieldset - Fieldset element
 * @csspart container - Container for checkboxes
 */
export declare class RadioGroup extends RadioGroup_base {
    #private;
    static styles: import("lit").CSSResult;
    /** @ignore */
    static formControlValidators: {
        attribute: string;
        key: string;
        message: () => string;
        isValid(instance: HTMLElement & {
            required: boolean;
        }, value: string): boolean; /**
         * Sets label of radio group
         */
    }[];
    /**
     * Sets label of radio group
     */
    label: string;
    /**
     * Sets value of radio group (string of value of checked option)
     */
    value: string | null;
    /**
     * Sets name of radio group (when set, it shows in form data)
     */
    name: string;
    /**
     * Sets radio group as required
     */
    required: boolean;
    /**
     * Sets radio group as disabled
     */
    disabled: boolean;
    /**
     * Sets helper text of input
     */
    helperText: string;
    /**
     * Fires when value of radio group changes
     * @ignore
     */
    private onChange;
    /**
     * Fires when state of radio group is invalid
     * @ignore
     */
    private onInvalid;
    /**
     * Signals that value of radio group changed
     * @ignore
     */
    private dirty;
    /**
     * Signals which option is focused
     * @ignore
     */
    private focusedOptionIndex;
    connectedCallback(): void;
    disconnectedCallback(): void;
    validityCallback(): string;
    updated(changedProperties: PropertyValues): Promise<void>;
    resetFormControl(): void;
    firstUpdated(): void;
    render(): TemplateResult;
}
export {};
//# sourceMappingURL=radio-group.d.ts.map