import { LitElement, PropertyValues, TemplateResult } from 'lit';
import '../label/index.js';
declare const Textarea_base: import("@open-wc/form-control").Constructor<import("@open-wc/form-control").FormControlInterface> & typeof LitElement;
/**
 * Allows user to provide multi-line text input.
 *
 * @element dfx-textarea
 * @fires {string} dfx-input - Fires when value changed on keyup
 * @fires {string} dfx-change - Fires when value changed and textarea is blurred
 * @fires {ValidityState} dfx-invalid - Fires when value is invalid
 * @cssprop [--dfx-textarea-border-radius=var(--dfx-border-radius-m, 0.375rem)] - Border radius
 * @cssprop [--dfx-textarea-color-background=var(--dfx-color-background-light, #ffffff)] - Textarea background
 * @cssprop [--dfx-textarea-color-text=var(--dfx-color-text-dark, #383d46)] - Textarea text color
 * @cssprop [--dfx-textarea-font-family=var(--dfx-font-family, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Arial, sans-serif)] - Textarea font family
 * @cssprop [--dfx-textarea-font-size=var(--dfx-font-size-m, 0.875rem)] - Textarea font size
 * @cssprop [--dfx-textarea-gap=var(--dfx-size-2xs, 0.5rem)] - Gap between textarea and label
 * @cssprop [--dfx-textarea-height=auto] - Textarea height
 * @cssprop [--dfx-textarea-line-height=var(--dfx-line-height-m, 1.5)] - Textarea line height
 * @cssprop [--dfx-textarea-padding=var(--dfx-size-2xs, 0.5rem) var(--dfx-size-xs, 0.75rem)] - Textarea padding
 * @cssprop [--dfx-textarea-transition=all var(--dfx-transition-medium, 0.2s ease-in-out)] - Textarea transition
 * @cssprop [--dfx-textarea-width=calc(var(--dfx-size-3xl, 2.5rem) * 5)] - Component width
 * @csspart textarea - Textarea element
 * @csspart container - Container element
 */
export declare class Textarea extends Textarea_base {
    #private;
    static styles: import("lit").CSSResult;
    /** @ignore */
    static formControlValidators: {
        key: keyof ValidityState;
        isValid(instance: HTMLElement & {
            validationTarget: HTMLInputElement;
        }): boolean;
    }[];
    /** @ignore */
    validationTarget: HTMLTextAreaElement;
    /**
     * Sets name of textarea
     */
    name: string;
    /**
     * Sets value of textarea
     */
    value: string;
    /**
     * Sets label of textarea
     */
    label: string;
    /**
     * Sets visible row count of textarea
     */
    rows: number;
    /**
     * Sets placeholder of textarea
     */
    placeholder: string;
    /**
     * Sets textarea as required
     */
    required: boolean;
    /**
     * Sets textarea validation of minimum length
     */
    minlength: number;
    /**
     * Sets textarea validation of maximum length
     */
    maxlength: number;
    /**
     * Sets textarea as disabled
     */
    disabled: boolean;
    /**
     * Sets textarea as readonly
     */
    readonly: boolean;
    /**
     * Sets helper text of textarea
     */
    helperText: string;
    /**
     * Hides label of textarea
     */
    hideLabel: boolean;
    /**
     * Enables spellcheck inside the textarea
     */
    spellchecker: boolean;
    /**
     * Enables character counter
     */
    characterCounter: boolean;
    /**
     * Fires when value of textarea changed on keyup
     * @ignore
     */
    private onInput;
    /**
     * Fires when value of textarea changed and textarea is blurred
     * @ignore
     */
    private onChange;
    /**
     * Fires when value of textarea is invalid
     * @ignore
     */
    private onInvalid;
    /**
     * Signals that value of input changed
     * @ignore
     */
    private dirty;
    connectedCallback(): void;
    disconnectedCallback(): void;
    validityCallback(): string;
    updated(changedProperties: PropertyValues): Promise<void>;
    resetFormControl(): void;
    render(): TemplateResult;
}
export {};
//# sourceMappingURL=textarea.d.ts.map